==> miniorange_saml-8.x-2.0.tar.gz: miniorange_saml/src/Form/Export.php <==
<?php

/**
 * @file
 * Contains \Drupal\miniorange_saml\Form\Export.
 */
namespace Drupal\miniorange_saml\Form;

use Drupal\Core\Form\FormBase;
use Drupal\miniorange_saml\MiniorangeSAMLConstants;
use Drupal\miniorange_saml\Utilities;

class Export extends FormBase
{	
  public function getFormId() 
  {
    return 'miniorange_saml_export';
  }
  public function buildForm(array $form, \Drupal\Core\Form\FormStateInterface $form_state) 
  {
      global $base_url;

      Utilities::visual_tour_start($form, $form_state);

      $form['markup_top_1'] = array (
          '#markup' => '<div class="mo_saml_table_layout_1"><div class="mo_saml_table_layout mo_saml_container">
                    <h2>Export/Import Configuration  <a id="Restart_moTour" class="btn btn-primary btn-sm mo_tour_button_float" onclick="Restart_moTour()">Take a Tour</a></h2><hr/>'
      );
      $form['markup_1'] = array(
          '#markup' => '<br><div class="mo_saml_highlight_background_note"><p><b>NOTE: </b>This tab will help you to transfer your module configurations when you change your Drupal instance. 
                        <br>Example: When you switch from test environment to production.<br>Follow these 3 simple steps to do that:<br>
                        <br><strong>1.</strong> Download module configuration file by clicking on the Download Configuration button given below.
                        <br><strong>2.</strong> Install the module on new Drupal instance.<br><strong>3.</strong> Upload the configuration file in Import module Configurations section.<br>
                        <br><b>And just like that, all your module configurations will be transferred!</b></p></div><div id="Exort_Configuration"><h3>Export Configuration &nbsp;&nbsp;</h3><hr/><p>
                        Click on the button below to download module configuration.</p>',
      );

      $login_URL = \Drupal::config('miniorange_saml.settings')->get('miniorange_saml_idp_login_url');
      $ACS_URL = \Drupal::config('miniorange_saml.settings')->get('miniorange_saml_idp_issuer');
      $disableButton = FALSE;
      if( $login_URL == NULL || $ACS_URL == NULL ){
          $disableButton = TRUE;
          $form['markup_note'] = array(
              '#markup' => '<div class="mo_saml_configure_message">Please <a href="' . $base_url . '/admin/config/people/miniorange_saml/sp_setup">configure module </a> first to download configuration file.</div><br>',
          );
      }

      $form['miniorange_saml_imo_option_exists_export'] = array(
          '#type' => 'submit',
          '#value' => t('Download Module Configuration'),
          '#submit' => array('::miniorange_import_export'),
          '#disabled' => $disableButton,
          '#suffix'=> '<br/><br/></div>',
      );

      $form['markup_prem_plan'] = array(
          '#markup' => '<div id="Import_Configuration"><br/><h3>Import Configuration</h3><hr><br>
                        <div class="mo_saml_highlight_background_note_1"><b>Note: </b>Available in 
                        <a href="' . $base_url . MiniorangeSAMLConstants::LICENSING_TAB_URL .'">Standard, Premium and Enterprise</a> versions of the module</div>',
      );

      $form['markup_import_note'] = array(
          '#markup' => '<p>This tab will help you to<span style="font-weight: bold"> Import your module configurations</span> when you change your Drupal instance.</p>
               <p>choose <b>"json"</b> Extened module configuration file and upload by clicking on the button given below. </p>',
      );

      $form['import_Config_file'] = array(
          '#type' => 'file',
          '#disabled' => TRUE,
      );

      $form['miniorange_saml_idp_import'] = array(
          '#type' => 'submit',
          '#value' => t('Upload'),
          '#disabled' => TRUE,
          '#suffix' => '<br><br><br><br><br></div></div>'
      );

      Utilities::spConfigGuide($form, $form_state);

      Utilities::AddSupportButton($form, $form_state);

      return $form;
	}
	function miniorange_import_export() 
	{
        $tab_class_name = array(
            'Service_Provider_Metadata' => 'mo_options_enum_identity_provider',
            'Identity_Provider_Setup' => 'mo_options_enum_service_provider',
        );

		$configuration_array = array();
		foreach($tab_class_name as $key => $value) {
			$configuration_array[$key] = self::mo_get_configuration_array($value);
		}

		$configuration_array["Version_dependencies"] = self::mo_get_version_informations();
		header("Content-Disposition: attachment; filename = miniorange_saml_config.json");
		echo(json_encode($configuration_array, JSON_PRETTY_PRINT|JSON_UNESCAPED_SLASHES));
		exit;
	}

    function mo_get_configuration_array($class_name)
    {
        $class_object = Utilities::getVariableArray($class_name);
        $mo_array = array();
        foreach($class_object as $key => $value) {
            $mo_option_exists = \Drupal::config('miniorange_saml.settings')->get($value);
            if($mo_option_exists) {
                $mo_array[$key] = $mo_option_exists;
            }
        }
        return $mo_array;
    }

    function mo_get_version_informations() {
        $array_version = array();
        $array_version["PHP_version"] = phpversion();
        $array_version["Drupal_version"] = \DRUPAL::VERSION;
        $array_version["OPEN_SSL"] = self::mo_saml_is_openssl_installed();
        $array_version["CURL"] = self::mo_saml_is_curl_installed();
        $array_version["ICONV"] = self::mo_saml_is_iconv_installed();
        $array_version["DOM"] = self::mo_saml_is_dom_installed();
        return $array_version;
    }

	function mo_saml_is_openssl_installed() {
		if ( in_array( 'openssl', get_loaded_extensions() ) ) {
			return 1;
		} else {
			return 0;
		}
	}
    function mo_saml_is_curl_installed() {
        if ( in_array( 'curl', get_loaded_extensions() ) ) {
            return 1;
        } else {
            return 0;
        }
    }
    function mo_saml_is_iconv_installed() {
        if ( in_array( 'iconv', get_loaded_extensions() ) ) {
            return 1;
        } else {
            return 0;
        }
    }
    function mo_saml_is_dom_installed() {
        if ( in_array( 'dom', get_loaded_extensions() ) ) {
            return 1;
        } else {
            return 0;
        }
    }

    public function submitForm(array &$form, \Drupal\Core\Form\FormStateInterface $form_state) {

    }
}

==> miniorange_saml-8.x-2.11.tar.gz: miniorange_saml/src/Form/Export.php <==
<?php

/**
 * @file
 * Contains \Drupal\miniorange_saml\Form\Export.
 */
namespace Drupal\miniorange_saml\Form;

use Drupal\Core\Form\FormBase;
use Drupal\miniorange_saml\MiniorangeSAMLConstants;
use Drupal\miniorange_saml\Utilities;

class Export extends FormBase
{	
  public function getFormId() 
  {
    return 'miniorange_saml_export';
  }
  public function buildForm(array $form, \Drupal\Core\Form\FormStateInterface $form_state) 
  {
      global $base_url;

      Utilities::visual_tour_start($form, $form_state);

      $form['markup_top_1'] = array (
          '#markup' => '<div class="mo_saml_table_layout_1"><div class="mo_saml_table_layout mo_saml_container">
                    <h2>Export/Import Configuration  <a id="Restart_moTour" class="mo_btn mo_btn-primary mo_btn-sm mo_tour_button_float" onclick="Restart_moTour()">Take a Tour</a></h2><hr/>'
      );
      $form['markup_1'] = array(
          '#markup' => '<br><div class="mo_saml_highlight_background_note"><p><b>NOTE: </b>This tab will help you to transfer your module configurations when you change your Drupal instance. 
                        <br>Example: When you switch from test environment to production.<br>Follow these 3 simple steps to do that:<br>
                        <br><strong>1.</strong> Download module configuration file by clicking on the Download Configuration button given below.
                        <br><strong>2.</strong> Install the module on new Drupal instance.<br><strong>3.</strong> Upload the configuration file in Import module Configurations section.<br>
                        <br><b>And just like that, all your module configurations will be transferred!</b></p></div><div id="Exort_Configuration"><h3>Export Configuration &nbsp;&nbsp;</h3><hr/><p>
                        Click on the button below to download module configuration.</p>',
      );

      $login_URL = \Drupal::config('miniorange_saml.settings')->get('miniorange_saml_idp_login_url');
      $ACS_URL = \Drupal::config('miniorange_saml.settings')->get('miniorange_saml_idp_issuer');
      $disableButton = FALSE;
      if( $login_URL == NULL || $ACS_URL == NULL ){
          $disableButton = TRUE;
          $form['markup_note'] = array(
              '#markup' => '<div class="mo_saml_configure_message">Please <a href="' . $base_url . '/admin/config/people/miniorange_saml/sp_setup">configure module </a> first to download configuration file.</div><br>',
          );
      }

      $form['miniorange_saml_imo_option_exists_export'] = array(
          '#type' => 'submit',
          '#value' => t('Download Module Configuration'),
          '#submit' => array('::miniorange_import_export'),
          '#disabled' => $disableButton,
          '#suffix'=> '<br/><br/></div>',
      );

      $form['markup_prem_plan'] = array(
          '#markup' => '<div id="Import_Configuration"><br/><h3>Import Configuration</h3><hr><br>
                        <div class="mo_saml_highlight_background_note_1"><b>Note: </b>Available in 
                        <a href="' . $base_url . MiniorangeSAMLConstants::LICENSING_TAB_URL .'">Standard, Premium and Enterprise</a> versions of the module</div>',
      );

      $form['markup_import_note'] = array(
          '#markup' => '<p>This tab will help you to<span style="font-weight: bold"> Import your module configurations</span> when you change your Drupal instance.</p>
               <p>choose <b>"json"</b> Extened module configuration file and upload by clicking on the button given below. </p>',
      );

      $form['import_Config_file'] = array(
          '#type' => 'file',
          '#disabled' => TRUE,
      );

      $form['miniorange_saml_idp_import'] = array(
          '#type' => 'submit',
          '#value' => t('Upload'),
          '#disabled' => TRUE,
          '#suffix' => '<br><br><br><br><br></div></div>'
      );

      Utilities::spConfigGuide($form, $form_state);

      Utilities::AddSupportButton($form, $form_state);

      return $form;
	}
	function miniorange_import_export() 
	{
        $tab_class_name = array(
            'Service_Provider_Metadata' => 'mo_options_enum_identity_provider',
            'Identity_Provider_Setup' => 'mo_options_enum_service_provider',
        );

		$configuration_array = array();
		foreach($tab_class_name as $key => $value) {
			$configuration_array[$key] = self::mo_get_configuration_array($value);
		}

		$configuration_array["Version_dependencies"] = self::mo_get_version_informations();
		header("Content-Disposition: attachment; filename = miniorange_saml_config.json");
		echo(json_encode($configuration_array, JSON_PRETTY_PRINT|JSON_UNESCAPED_SLASHES));
		exit;
	}

    function mo_get_configuration_array($class_name)
    {
        $class_object = Utilities::getVariableArray($class_name);
        $mo_array = array();
        foreach($class_object as $key => $value) {
            $mo_option_exists = \Drupal::config('miniorange_saml.settings')->get($value);
            if($mo_option_exists) {
                $mo_array[$key] = $mo_option_exists;
            }
        }
        return $mo_array;
    }

    function mo_get_version_informations() {
        $array_version = array();
        $array_version["PHP_version"] = phpversion();
        $array_version["Drupal_version"] = \DRUPAL::VERSION;
        $array_version["OPEN_SSL"] = self::mo_saml_is_openssl_installed();
        $array_version["CURL"] = self::mo_saml_is_curl_installed();
        $array_version["ICONV"] = self::mo_saml_is_iconv_installed();
        $array_version["DOM"] = self::mo_saml_is_dom_installed();
        return $array_version;
    }

	function mo_saml_is_openssl_installed() {
		if ( in_array( 'openssl', get_loaded_extensions() ) ) {
			return 1;
		} else {
			return 0;
		}
	}
    function mo_saml_is_curl_installed() {
        if ( in_array( 'curl', get_loaded_extensions() ) ) {
            return 1;
        } else {
            return 0;
        }
    }
    function mo_saml_is_iconv_installed() {
        if ( in_array( 'iconv', get_loaded_extensions() ) ) {
            return 1;
        } else {
            return 0;
        }
    }
    function mo_saml_is_dom_installed() {
        if ( in_array( 'dom', get_loaded_extensions() ) ) {
            return 1;
        } else {
            return 0;
        }
    }

    public function submitForm(array &$form, \Drupal\Core\Form\FormStateInterface $form_state) {

    }
}
